use std::str::FromStr;

use serde::Deserialize;

pub(crate) trait Merge {
    fn merge(self, other: Self) -> Self;
}

#[derive(Debug, Default, Deserialize)]
pub(crate) struct Config {
    pub syntect: Syntect,
}

impl FromStr for Config {
    type Err = toml::de::Error;

    fn from_str(s: &str) -> Result<Self, Self::Err> {
        toml::from_str(s)
    }
}

impl Merge for Config {
    fn merge(self, other: Self) -> Self {
        Self {
            syntect: self.syntect.merge(other.syntect),
        }
    }
}

#[derive(Debug, Default, Deserialize)]
pub(crate) struct Syntect {
    pub theme: Option<String>,
    pub theme_dir: Option<String>,
}

impl Merge for Syntect {
    fn merge(self, other: Syntect) -> Self {
        Self {
            theme: self.theme.or(other.theme),
            theme_dir: self.theme_dir.or(other.theme_dir)
        }
    }
}

